@@ -1,10 +1,9 @@
 # Copyright (C) 2017-2021 Lebai Robotics
-# Author: kingfree
-# Contact: kingfree@toyama.moe
+# Author: rozow
+# Contact: rongzong123@foxmail.com
 
 """Lebai Robot Python SDK"""
 
 from .type import RobotState, TaskStatus, IODeviceType, CartesianPose, JointPose, Error, RequestError
-from .robot_async import LebaiRobotAsync
 from .robot import LebaiRobot
 from .scene import LebaiScene
