@@ -8,6 +8,7 @@ from lebai.pb2 import private_controller_pb2_grpc
 from lebai.pb2 import robot_controller_pb2_grpc
 from lebai.pb2.private_controller_pb2 import DHRequest, DHt
 from .type import *
+import time
 
 
 class LebaiRobot:
@@ -351,6 +352,37 @@ class LebaiRobot:
         self.rcs.SetClawForce(rc.Force(force=force))
         self.rcs.SetClawAmplitude(rc.Amplitude(amplitude=amplitude))
 
+    def towardj(self, p: object, a: float = 0, v: float = 0, is_joint=None) -> None:
+        """
+        线性移动（关节空间）
+
+        :p: 传入JointPose或CartesianPose，JointPose` 关节位置，`CartesianPose` 空间位置（将通过运动学反解转为关节位置）
+        :a: 主轴的关节加速度 (rad/s)
+        :v: 主轴的关节速度 (rad/s)
+        :t: 运动时间 (s)
+        :r: 交融半径 (m)
+        :is_joint: 已弃用
+
+        示例：
+
+        >>> self.movej(JointPose(0, -0.7853981633974483, 1.5707963267948966, -0.7853981633974483, 1.5707963267948966, 0),1.23,1.23)
+        """
+        if type(p) is not CartesianPose and type(p) is not JointPose:
+            raise Exception("请传入 CartesianPose 或 JointPose")
+        is_joint = getattr(p, 'is_joint', True)
+        if not hasattr(p, 'pos'):
+            p = JointPose(*p)
+        req = rc.MoveJRequest(
+            joint_pose_to=list(p.pos),
+            pose_is_joint_angle=is_joint,
+            acceleration=a,
+            velocity=v,
+            time=0,
+            blend_radius=0
+        )
+        if type(p) is CartesianPose:
+            p._base_set_PR(req.pose_base)
+        self.rcs.TowardJ(req)
     def movej(self, p: object, a: float = 0, v: float = 0, t: float = 0, r: float = 0, is_joint=None) -> None:
         """
         线性移动（关节空间）
@@ -979,7 +1011,7 @@ class LebaiRobot:
         self._sync()
         self.pcs.EnableJointLimit(pc.TrueOrFalse(val=False))
 
-    def run_scene(self, scene_id: int, execute_count: int = 1, clear: bool = True) -> int:
+    def run_scene(self, scene_id: int, execute_count: int = 1, clear: bool = True, timeout: int = 0) -> TaskStatus:
         """
         运行场景
 
@@ -988,7 +1020,14 @@ class LebaiRobot:
         :param clear: 是否强制关闭正在运行的任务
         :return: 任务Id
         """
-        return self.http_service.run_scene(scene_id, execute_count, clear)['id']
+        taks_id = self.http_service.run_scene(scene_id, execute_count, clear)['id']
+        t0 = time.time()
+        while time.time() - t0 < timeout:
+            task_info = self.http_service.get_task(taks_id)
+            if task_info.status != TaskStatus.RUNNING:
+                return task_info.status
+            time.sleep(0.1)
+        return TaskStatus.TIMEOUT
 
     def rerun_task(self, task_id: int, execute_count: int = 1, clear: bool = True) -> int:
         """
