@@ -61,6 +61,8 @@ class TaskStatus(Enum):
     """异常终止"""
     UNSTARTED = None
     """未启动"""
+    TIMEOUT = 6
+    """未启动"""
 
 
 class IODeviceType(Enum):
@@ -89,9 +91,9 @@ class CartesianPose:
 
     def __init__(self, x=0, y=0, z=0, rz=0, ry=0, rx=0, base=None):
         # print(x, hasattr(x, '__iter__'), hasattr(x, '__iter__'), type(x))
-        if type(x) is msg.PR:
+        if type(x) is msg.PR: # rpy -> ypr
             self.pos = [x.position.x, x.position.y, x.position.z,
-                        x.rotation.r, x.rotation.p, x.rotation.y]
+                        x.rotation.y, x.rotation.p, x.rotation.r]
         elif hasattr(x, 'pos'):
             self.pos = list(x.pos[:])
             if hasattr(x, 'base'):
@@ -144,17 +146,17 @@ class CartesianPose:
 
     def _to_PR(self):
         p = msg.Coordinate(x=self.pos[0], y=self.pos[1], z=self.pos[2])
-        r = msg.Rotation(r=self.pos[3], p=self.pos[4], y=self.pos[5])
+        r = msg.Rotation(y=self.pos[3], p=self.pos[4], r=self.pos[5]) # rpy -> ypr
         return msg.PR(position=p, rotation=r)
 
-    def _base_set_PR(self, pr):
+    def _base_set_PR(self, pr): # rpy -> ypr
         if self.base is not None:
             pr.position.x = self.base[0]
             pr.position.y = self.base[1]
             pr.position.z = self.base[2]
-            pr.rotation.r = self.base[3]
+            pr.rotation.y = self.base[3]
             pr.rotation.p = self.base[4]
-            pr.rotation.y = self.base[5]
+            pr.rotation.r = self.base[5]
 
     def _to_Vector(self):
         return rc.Vector(vector=self.pos)
